Returns the sequence number of the change within its actor's history. Sequence numbers start at 1 and increment with each change by the same actor.
Arguments
- change
An
am_changeobject (fromam_get_changes()oram_change_from_bytes())
Returns the sequence number of the change within its actor's history. Sequence numbers start at 1 and increment with each change by the same actor.
An am_change object (from am_get_changes() or
am_change_from_bytes())