Skip to content

Returns the actor ID of an Automerge document as a raw vector. The actor ID uniquely identifies the editing session that created changes in the document.

Usage

am_get_actor(doc)

Arguments

doc

An Automerge document

Value

A raw vector containing the actor ID bytes

Details

For a hex string representation, use am_get_actor_hex().

Examples

doc <- am_create()
actor <- am_get_actor(doc)
actor
#>  [1] 1c 52 35 f7 e2 e0 cf 80 b7 3b cf f8 47 90 ba 37

# Use am_get_actor_hex() for display
actor_hex <- am_get_actor_hex(doc)
cat("Actor ID:", actor_hex, "\n")
#> Actor ID: 1c5235f7e2e0cf80b73bcff84790ba37 

am_close(doc)