Returns the number of operations contained in the change. Useful for estimating the size of changes before syncing or storing them.
Arguments
- change
An
am_changeobject (fromam_get_changes()oram_change_from_bytes())
Returns the number of operations contained in the change. Useful for estimating the size of changes before syncing or storing them.
An am_change object (from am_get_changes() or
am_change_from_bytes())