Returns the timestamp recorded when the change was committed. Note that timestamps are set by the committing peer and may not be accurate if the peer's clock is wrong.
Arguments
- change
An
am_changeobject (fromam_get_changes()oram_change_from_bytes())