Tests whether two Automerge documents have the same content. Documents are equal if they have the same set of changes applied, regardless of how they were created.
Tests whether two Automerge documents have the same content. Documents are equal if they have the same set of changes applied, regardless of how they were created.