Returns the actor ID of an Automerge document as a raw vector. The actor ID uniquely identifies the editing session that created changes in the document.
Details
For a hex string representation, use am_get_actor_hex().
Examples
doc <- am_create()
actor <- am_get_actor(doc)
actor
#> [1] db 80 11 61 25 a4 be 02 51 68 cd dd f1 20 ae d5
# Use am_get_actor_hex() for display
actor_hex <- am_get_actor_hex(doc)
cat("Actor ID:", actor_hex, "\n")
#> Actor ID: db80116125a4be025168cdddf120aed5
am_close(doc)