Deserializes an Automerge document from the standard binary format. The binary format is compatible across all Automerge implementations (JavaScript, Rust, etc.).
Examples
# Create, save, and reload
doc1 <- am_create()
bytes <- am_save(doc1)
doc2 <- am_load(bytes)
doc2
#> <Automerge Document>
#> Actor: e5882ae5529df6d9ec19133566f7bb55
#> Root keys: 0
# Save to and load from file
doc3 <- am_create()
file <- tempfile()
writeBin(am_save(doc3), file)
doc4 <- am_load(readBin(file, "raw", 1e5))
unlink(file)
am_close(doc1)
am_close(doc2)
am_close(doc3)
am_close(doc4)