Serializes only the changes made since the last call to am_save() or
am_save_incremental(). This is more efficient than saving the entire
document when only a few changes have been made.
Value
A raw vector containing the incremental changes. May be empty (zero-length) if no new changes have been made since the last save.
Details
Use am_load_incremental() to apply these changes to another document.